ctao-sat 0.1.0-rc1 (2026-01-27)
-------------------------------

This is the first release candidate of the CTAO Science Analysis Tools.
It sets up the project structure, documentation, integrates with the CTAO AIV Toolkit,
and includes initial tests cases to showcase the AIV workflows and CI/CD setup.


New Features
~~~~~~~~~~~~

- Requires Gammapy v2.0.1

- Integrate AIV Toolkit [`!6 <https://gitlab.cta-observatory.org/cta-computing/suss/science-analysis-tools/science-analysis-tools/-/merge_requests/6>`__] [`!21 <https://gitlab.cta-observatory.org/cta-computing/suss/science-analysis-tools/science-analysis-tools/-/merge_requests/21>`__]

- Add test for 1D analysis use case (UC-100-1.0) [`!10 <https://gitlab.cta-observatory.org/cta-computing/suss/science-analysis-tools/science-analysis-tools/-/merge_requests/10>`__]

- Add test for 3D analysis use case  (UC-100-2.0) [`!15 <https://gitlab.cta-observatory.org/cta-computing/suss/science-analysis-tools/science-analysis-tools/-/merge_requests/15>`__]

- Add test for source finding use case (UC-100-3.0) [`!17 <https://gitlab.cta-observatory.org/cta-computing/suss/science-analysis-tools/science-analysis-tools/-/merge_requests/17>`__]
